import React, { useCallback, useEffect, useRef, useState } from "react";
import { withStyles } from "@diana-ui/base";
import { useRegistry } from "@diana-ui/hooks";
const styleSheet = theme => ({
    chipList: {
        display: "flex",
        overflowX: "auto"
    },
    chipContainer: {
        marginRight: theme.spaceUnit.xxs,
        marginTop: theme.spaceUnit.xs,
        marginBottom: theme.spaceUnit.xs,
        ":last-child": {
            marginRight: 0
        }
    }
});
function ChipList({ styles, cx, list = [], displayFn = (item) => item, onDismissChip, onListChange, wrappedRef, parentStylesheet, ...props }) {
    const [_list, setList] = useState(list);
    const divRef = useRef(null);
    const CloseableChipStyle = useRegistry("CloseableChip");
    useEffect(() => {
        setList(list);
        setTimeout(() => {
            if (divRef?.current) {
                divRef.current.scrollLeft = divRef.current.scrollWidth;
            }
        });
    }, [list, onListChange]);
    const handleDismiss = useCallback((item, index) => {
        const newList = _list.filter((_, i) => i !== index);
        setList(newList);
        if (onListChange) {
            onListChange(newList);
        }
        if (onDismissChip) {
            onDismissChip(item);
        }
    }, [_list, onDismissChip, onListChange]);
    return (React.createElement("div", Object.assign({ className: cx(styles.chipList) }, props, { ref: divRef }), _list.map((item, i) => (React.createElement("div", { className: cx(styles.chipContainer), key: i },
        React.createElement(CloseableChipStyle, { onClose: () => handleDismiss(item, i) }, displayFn(item)))))));
}
export default withStyles(styleSheet, { register: true })(ChipList);
