import React, { useRef, useImperativeHandle, useMemo } from "react";
import { withStyles } from "@diana-ui/base";
import { useRegistryWithStyles } from "@diana-ui/hooks";
export const styleSheet = () => ({
    header: {},
    label: {},
    text: {
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap"
    },
    list: {
        marginBottom: 0,
        marginTop: 0,
        paddingLeft: 0,
        listStyle: "none",
        overflowY: "auto"
    },
    item: {
        cursor: "pointer"
    },
    itemSelected: {},
    itemText: {
        display: "block",
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap"
    }
});
export const styleSheetPopover = () => ({
    container: {
        maxWidth: "100%"
    }
});
export const usePopoverRef = (wrappedRef) => {
    const ref = useRef(null);
    useImperativeHandle(wrappedRef, () => ({
        show: () => ref.current?.show(),
        hide: () => ref.current?.hide(),
        toggle: () => ref.current?.toggle()
    }));
    return ref;
};
export const DropdownHeader = ({ label, text, cx, styles }) => (React.createElement("div", { className: cx(styles.header) },
    label && React.createElement("div", { className: cx(styles.label) }, label),
    React.createElement("div", { className: cx(styles.text) }, text)));
const BaseDropdown = props => {
    const { items, onItemSelected, selectedItem, styles, cx, label, placeholder, text, renderItem, renderHeader, wrappedRef } = props;
    const ref = usePopoverRef(wrappedRef);
    const StyledPopover = useRegistryWithStyles("Popover", styleSheetPopover);
    const hide = () => ref.current?.hide();
    const header = useMemo(() => renderHeader?.() ?? (React.createElement(DropdownHeader, { label: label, text: text ?? (selectedItem ? selectedItem.text : placeholder), cx: cx, styles: styles })), [renderHeader, label, text, selectedItem, placeholder, cx, styles]);
    return (React.createElement(StyledPopover, Object.assign({ wrappedRef: ref }, props, { header: header }),
        React.createElement("ul", { className: cx(styles.list) }, items.map((item, index) => (React.createElement("li", { className: cx(styles.item, selectedItem?.id === item.id ? styles.itemSelected : {}), key: item.id, onClick: () => {
                onItemSelected(item);
                hide();
            }, role: "presentation" }, renderItem?.(item, selectedItem !== undefined && selectedItem.id === item.id, index) ?? React.createElement("span", { className: cx(styles.itemText) }, item.text)))))));
};
export const Dropdown = withStyles(styleSheet)(BaseDropdown);
export default Dropdown;
