import React, { useCallback } from "react";
import { useForm, Controller } from "react-hook-form";
import { withStyles } from "@diana-ui/base";
import { Checkbox } from "@diana-ui/checkbox";
import { TextInput, ErrorTextInput } from "@diana-ui/textinput";
const stylesheet = () => ({
    form: {
        display: "flex",
        flexDirection: "column"
    }
});
const Form = ({ children, cx, styles, onSubmit, clearOnSubmit = true, defaultValues, schema, parentStylesheet, ...props }) => {
    const { handleSubmit, errors, control, reset } = useForm({
        validationSchema: schema,
        defaultValues
    });
    const onSubmitCallback = useCallback((data, e) => {
        if (onSubmit) {
            onSubmit(data);
        }
        if (clearOnSubmit && schema) {
            e.preventDefault();
            let obj = {};
            Object.keys(schema.fields).forEach((f) => {
                // eslint-disable-next-line no-underscore-dangle
                const type = schema.fields[f]._type;
                if (type === "string") {
                    obj[f] = "";
                }
                if (type === "boolean") {
                    obj[f] = false;
                }
            });
            if (defaultValues) {
                obj = { ...obj, ...defaultValues };
            }
            reset(obj);
        }
    }, [defaultValues, schema, clearOnSubmit, reset, onSubmit]);
    return (React.createElement("form", Object.assign({}, props, { className: cx(styles.form), onSubmit: handleSubmit(onSubmitCallback) }), React.Children.map(children, (Child) => {
        if (Child.type === ErrorTextInput || Child.type === TextInput) {
            const error = errors[Child.props.name];
            return (React.createElement(Controller, { as: React.cloneElement(Child, {
                    error: error?.message
                }), value: Child.props.value, name: Child.props.name, control: control, defaultValue: "" }));
        }
        if (Child.type === Checkbox) {
            return (React.createElement(Controller, { as: Child, onChange: ([checked]) => {
                    return checked.currentTarget.checked;
                }, name: Child.props.name, control: control }));
        }
        return Child;
    })));
};
export default withStyles(stylesheet)(Form);
