import React, { useCallback, useImperativeHandle, useState, useRef } from "react";
import { withStyles } from "@diana-ui/base";
import { useOnClickOutside } from "@diana-ui/hooks";
const styleSheet = () => ({
    container: {
        position: "relative"
    },
    disabled: {
        pointerEvents: "none"
    },
    header: {
        cursor: "pointer"
    },
    popover: {
        position: "absolute",
        width: "100%"
    },
    bottom: {
        top: "100%"
    },
    top: {
        bottom: "100%"
    },
    left: {
        top: 0,
        bottom: 0,
        right: "100%"
    },
    right: {
        top: 0,
        bottom: 0,
        left: "100%"
    }
});
const Popover = ({ direction = "bottom", dismissOnClick = true, children, header, onShow, onHide, disabled = false, cx, styles, wrappedRef }) => {
    const [visible, _setVisible] = useState(false);
    const setVisible = useCallback((newVisible) => {
        const handler = newVisible ? onShow : onHide;
        if (handler) {
            handler();
        }
        _setVisible(newVisible);
    }, [_setVisible, onShow, onHide]);
    const divRef = useRef(null);
    useOnClickOutside(divRef, () => dismissOnClick && setVisible(false));
    const toggleVisible = useCallback(() => setVisible(!visible), [
        visible,
        setVisible
    ]);
    useImperativeHandle(wrappedRef, () => ({
        show: () => setVisible(true),
        hide: () => setVisible(false),
        toggle: () => toggleVisible()
    }));
    return (React.createElement("div", { className: cx(styles.container, disabled && styles.disabled), ref: divRef },
        React.createElement("div", { className: cx(styles.header), onClick: () => {
                if (!disabled) {
                    toggleVisible();
                }
            } }, header),
        visible && (React.createElement("div", { className: cx(styles.popover, styles[direction]) }, children))));
};
export default withStyles(styleSheet, { register: true })(Popover);
