import React, { useCallback, useMemo } from "react";
import uuid from "uuid/v4";
import { withStyles } from "@diana-ui/base";
import { Text } from "@diana-ui/typography";
const styleSheet = theme => ({
    input: {
        color: theme.colors.primary,
        cursor: "pointer",
        ":hover": {},
        ":active": {},
        "@selectors": {
            "&.checked": {},
            "&.disabled": {
                cursor: "default"
            },
            "&.error": {}
        }
    },
    label: {
        cursor: "pointer",
        ":hover": {},
        ":active": {},
        "@selectors": {
            "&.checked": {},
            "&.disabled": {
                cursor: "default"
            },
            "&.error": {
                color: theme.colors.alert.alert50
            }
        }
    },
    wrapper: {
        display: "flex",
        alignItems: "center",
        "@selectors": {
            "&.checked": {},
            "&.disabled": {},
            "&.error": {
                color: theme.colors.alert.alert50
            }
        }
    }
});
const Radio = ({ children, cx, hasError, label, selectedValue, styles, wrappedRef, onValueSelect, parentStylesheet, ...props }) => {
    const id = useMemo(() => uuid(), []);
    const { value, disabled } = props;
    const isChecked = selectedValue === value;
    const handleChange = useCallback(() => {
        if (!disabled && onValueSelect) {
            onValueSelect(value);
        }
    }, [disabled, value, onValueSelect]);
    const inputStyles = cx(styles.input, isChecked && "checked", disabled && "disabled", hasError && "error", children && children.props.className);
    const labelStyles = cx(styles.label, isChecked && "checked", disabled && "disabled", hasError && "error");
    return (React.createElement("div", { className: cx(styles.wrapper) },
        React.createElement("input", Object.assign({ checked: isChecked, className: children ? cx({ display: "none" }) : inputStyles, id: id, ref: wrappedRef, type: "radio", onChange: handleChange }, props)),
        children &&
            React.cloneElement(children, {
                className: inputStyles,
                onClick: handleChange
            }),
        React.createElement("label", { htmlFor: id, className: labelStyles },
            React.createElement(Text, null, label))));
};
export default withStyles(styleSheet)(Radio);
