import React, { useCallback, useEffect, useImperativeHandle, useState } from "react";
import { withStyles } from "@diana-ui/base";
const styleSheet = () => ({
    radioGroup: {
        display: "flex",
        flexDirection: "column",
        justifyContent: "space-between"
    }
});
const RadioGroup = ({ children, cx, disabled, initialValue, selectedValue, styles, onValueSelect, wrappedRef, ...props }) => {
    const [selected, setSelected] = useState(initialValue);
    // state is being controlled by the parent component
    useEffect(() => {
        if (typeof selectedValue !== "undefined") {
            setSelected(selectedValue);
        }
    }, [selectedValue]);
    const handleValueSelect = useCallback(newValue => {
        // state is being controlled internally
        if (selectedValue === undefined) {
            setSelected(newValue);
        }
        if (onValueSelect) {
            onValueSelect(newValue);
        }
    }, [onValueSelect, selectedValue]);
    useImperativeHandle(wrappedRef, () => ({
        setSelectedValue: newValue => setSelected(newValue)
    }));
    return (React.createElement("div", { className: cx(styles.radioGroup) }, React.Children.map(children, child => React.cloneElement(child, {
        disabled: child.props.disabled ?? disabled,
        selectedValue: selected,
        onValueSelect: handleValueSelect,
        ...props
    }))));
};
export default withStyles(styleSheet)(RadioGroup);
