import React, { useCallback, useEffect, useImperativeHandle, useState } from "react";
import { withStyles } from "@diana-ui/base";
const styleSheet = () => ({
    tabGroup: {
        display: "flex",
        margin: "0",
        padding: "0"
    },
    tabPanel: {}
});
const TabGroup = ({ children, className, cx, disabled, initialTab = 0, selectedTab, styles, wrappedRef, onTabClick }) => {
    const [selected, setSelected] = useState(initialTab);
    // state is being controlled by the parent component
    useEffect(() => {
        if (typeof selectedTab !== "undefined") {
            setSelected(selectedTab);
        }
    }, [selectedTab]);
    const handleTabClick = useCallback(newTab => {
        // state is being controlled internally
        if (selectedTab === undefined) {
            setSelected(newTab);
        }
        if (onTabClick) {
            onTabClick(newTab);
        }
    }, [onTabClick, selectedTab]);
    useImperativeHandle(wrappedRef, () => ({
        setTab: newTab => setSelected(newTab)
    }));
    return (React.createElement(React.Fragment, null,
        React.createElement("ul", { className: cx(className, styles.tabGroup) }, React.Children.map(children, (tab, index) => React.cloneElement(tab, {
            disabled: tab.props.disabled ?? disabled,
            index,
            selectedTab: selected,
            onTabClick: handleTabClick
        }))),
        React.createElement("section", { className: cx(styles.tabPanel) }, children[selected].props.children)));
};
export default withStyles(styleSheet)(TabGroup);
